blob: 008e72e04afdf2351c5b9acd80c7a96fce6de554 (
plain) (
blame)
1
2
3
4
5
6
7
8
9
10
11
12
13
14
15
16
17
18
|
# Kagamic
## TODO
- Testing setup
- Vec_get not safe, I made a type mistake. And should be more efficient for loops
- Fix tests in release
- Benchmark 100MB file
- json.loads: 526 ms ± 77 ms per loop (mean ± std. dev. of 7 runs, 1 loop each)
- Vec_new returns pointer
- More modern include pragma (once)
- File structure
- Static functions for private?
- JSON float
## Resources
- https://nullprogram.com/blog/2023/10/08/
|